@@ -6,13 +6,13 @@ from easydata.queries.key import KeyQuery
 
 
 class JmesPathSearch(KeyQuery):
-    def parse(
+    def _parse(
         self,
         data: Any,
     ):
 
         data = jmespath.search(
-            expression=self.query,
+            expression=self._query,
             data=data,
         )
 
