@@ -16,28 +16,28 @@ class ReQuery(QuerySearch):
         bytes_to_string_decode: str = "utf-8",
     ):
 
-        self.query = re.compile(query, flag)
-        self.bytes_to_string_decode = bytes_to_string_decode
+        self._query = re.compile(query, flag)
+        self._bytes_to_string_decode = bytes_to_string_decode
 
-    def parse(
+    def _parse(
         self,
         data: Any,
     ):
 
-        for result in self.iter_parse(data):
+        for result in self._iter_parse(data):
             return result
 
-    def iter_parse(
+    def _iter_parse(
         self,
         data: Any,
     ) -> Iterable[Any]:
 
-        results = re.finditer(self.query, data)
+        results = re.finditer(self._query, data)
 
         for result in results:
             yield result.group(1)
 
-    def process_data(
+    def _process_data(
         self,
         data: Any,
         source: Optional[str] = None,
@@ -53,7 +53,7 @@ class ReQuery(QuerySearch):
             data = dumps(data)
 
         if isinstance(data, bytes):
-            data = data.decode(self.bytes_to_string_decode)
+            data = data.decode(self._bytes_to_string_decode)
 
         if not isinstance(data, str):
             raise TypeError("Provided data must be string in order to make re search")
